@@ -1,10 +1,13 @@
 package DateTime::Calendar::Christian;
 
+use 5.008004;
+
 use strict;
+use warnings;
 
 use vars qw($VERSION);
 
-$VERSION = '0.04';
+$VERSION = '0.05';
 
 use DateTime 0.1402;
 use DateTime::Calendar::Julian 0.04;
@@ -117,8 +120,8 @@ sub new {
                            minute => { type => SCALAR, default => 0 },
                            second => { type => SCALAR, default => 0 },
                            nanosecond => { type => SCALAR, default => 0 },
-                           language  => { type => SCALAR | OBJECT,
-                                          default => $class->DefaultLanguage },
+                           locale  => { type => SCALAR | OBJECT,
+                                          default => $class->DefaultLocale },
                            time_zone => { type => SCALAR | OBJECT,
                                           default => 'floating' },
                            reform_date => { type => SCALAR | OBJECT,
@@ -181,6 +184,8 @@ sub from_epoch {
 }
 
 sub now { shift->from_epoch( epoch => (scalar time), @_ ) }
+ 
+sub today { shift->now(@_)->truncate( to => 'day' ) }
 
 sub from_object {
     my $class = shift;
@@ -407,7 +412,7 @@ sub set {
         ( reform_date => $self->{reform_date},
           map { $_ => $self->$_() }
             qw( year month day hour minute second nanosecond
-                language time_zone )
+                locale time_zone )
         );
 
     my $new_dt = (ref $self)->new( %old_p, %p );
@@ -450,7 +455,7 @@ for my $sub (qw/year ce_year month month_0 month_name month_abbr
                 day_name day_abbr ymd mdy dmy hour minute second hms
                 nanosecond millisecond microsecond
                 iso8601 datetime week_year week_number
-                time_zone offset is_dst time_zone_short_name language
+                time_zone offset is_dst time_zone_short_name locale
                 utc_rd_values utc_rd_as_seconds local_rd_as_seconds jd
                 mjd strftime epoch utc_year compare _compare_overload/,
              # these should be replaced with a corrected version
@@ -481,9 +486,9 @@ for my $sub (qw/year ce_year month month_0 month_name month_abbr
 *sec = \&second;
 *DateTime::Calendar::Christian::time = \&hms;
 
-sub DefaultLanguage {
+sub DefaultLocale {
     shift;
-    DateTime->DefaultLanguage(@_);
+    DateTime->DefaultLocale(@_);
 }
 
 1;
@@ -530,12 +535,13 @@ DateTime. See L<DateTime> for all other methods.
 =item * new( ... )
 
 Besides the usual parameters ("year", "month", "day", "hour", "minute",
-"second", "nanosecond", "fractional_seconds", "language" and "time_zone"),
+"second", "nanosecond", "fractional_seconds", "locale" and "time_zone"),
 this class method takes the
 additional "reform_date" parameter. This parameter can be a DateTime
 object (or an object that can be converted into a DateTime). This
 denotes the first date of the Gregorian calendar. It can also be a
-string, containing the name of a location, e.g. 'Italy'.
+string, containing the name of a location, e.g. 'Italy'. Location names
+are not case-sensitive.
 
 If this method is used as an instance method and no "reform_date" is
 given, the "reform_date" of the returned object is the same as the one
@@ -564,6 +570,50 @@ corresponding Julian date. This behaviour may change in future
 versions. If a date is given that can be both Julian and Gregorian, it
 will be considered Julian. This is a bug.
 
+The supported reform date location names are:
+
+ Italy -------------- 1582-10-15 # and some other Catholic countries
+ France ------------- 1582-12-20
+ Belgium ------------ 1583-1-1
+ Holland ------------ 1583-1-1   # or 1583-1-12?
+ Liege -------------- 1583-2-21
+ Augsburg ----------- 1583-2-24
+ Treves ------------- 1583-10-15
+ Bavaria ------------ 1583-10-16
+ Tyrolia ------------ 1583-10-16
+ Julich ------------- 1583-11-13
+ Cologne ------------ 1583-11-14 # or 1583-11-13?
+ Wurzburg ----------- 1583-11-15
+ Mainz -------------- 1583-11-22
+ Strasbourg_Diocese - 1583-11-27
+ Baden -------------- 1583-11-27
+ Carynthia ---------- 1583-12-25
+ Bohemia ------------ 1584-1-17
+ Lucerne ------------ 1584-1-22
+ Silesia ------------ 1584-1-23
+ Westphalia --------- 1584-7-12
+ Paderborn ---------- 1585-6-27
+ Hungary ------------ 1587-11-1
+ Transylvania ------- 1590-12-25
+ Prussia ------------ 1610-9-2
+ Hildesheim --------- 1631-3-26
+ Minden ------------- 1668-2-12
+ Strasbourg --------- 1682-2-16
+ Denmark ------------ 1700-3-1
+ Germany_Protestant - 1700-3-1
+ Gelderland --------- 1700-7-12
+ Faeror ------------- 1700-11-28 # or 1700-11-27?
+ Iceland ------------ 1700-11-28
+ Utrecht ------------ 1700-12-12
+ Zurich ------------- 1701-1-12
+ Friesland ---------- 1701-1-12  # or 1701-01-13?
+ Drente ------------- 1701-5-12  # or 1701-01-12?
+ UK ----------------- 1752-9-14
+ Bulgaria ----------- 1915-11-14 # or 1916-04-14?
+ Russia ------------- 1918-2-14
+ Latvia ------------- 1918-2-15
+ Romania ------------ 1919-4-14  # or 1924-10-14?
+
 =item * from_epoch
 
 This method accepts an additional "reform_date" argument. Note that the
@@ -613,8 +663,9 @@ fine; it's just the calendar reform dates that should be inside these
 limits.)
 
 =item * There may be functions that give the wrong results for the year
-of the calendar reform. The function L<truncate> is a known problem. If
-you find any more problems, please let me know.
+of the calendar reform. The function L<truncate> is a known problem, and
+L<today> may be a problem. If you find any more problems, please let me
+know.
 
 =back
 
@@ -627,12 +678,16 @@ list. See http://lists.perl.org/ for more details.
 
 Eugene van der Pijll <pijll@gmx.net>
 
+Thomas R. Wyant, III F<wyant at cpan dot org>
+
 =head1 COPYRIGHT
 
 Copyright (c) 2003 Eugene van der Pijll.  All rights reserved.  This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+Copyright (C) 2016 Thomas R. Wyamt, III
+
 =head1 SEE ALSO
 
 L<DateTime>, L<DateTime::Calendar::Julian>
